@@ -5,7 +5,7 @@ package App::Pastebin::Create;
 # FILE HOLDER/THIS IS COMMAND LINE APP, executable name is pastebin-create
 # The executable located in bin/
 # type pastebin -h for usage
-our $VERSION = '1.0020'; # VERSION
+our $VERSION = '1.0021'; # VERSION
 
 __END__
 
@@ -19,7 +19,7 @@ App::Pastebin::Create - Simple CLI App to create and upload to Pastebin.com
 
 =head1 VERSION
 
-version 1.0020
+version 1.0021
 
 =head1 SYNOPSIS
 
@@ -65,17 +65,9 @@ Your paste title description.
 
 =head1 SEE ALSO
 
-=over 4
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create>
 
-=item *
-
-L<WWW::Pastebin::PastebinCom::Create>
-
-=item *
-
-L<App::Nopaste>
-
-=back
+L<https://metacpan.org/pod/App::Nopaste>
 
 =head1 AUTHOR
 
